@@ -5,7 +5,6 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 
-import gdb
 import six
 
 import pwndbg.auxv
@@ -13,12 +12,9 @@ import pwndbg.chain
 import pwndbg.commands
 
 
-@pwndbg.commands.ParsedCommand
+@pwndbg.commands.ArgparsedCommand('Print information from the Auxiliary ELF Vector.')
 @pwndbg.commands.OnlyWhenRunning
 def auxv():
-    """
-    Print information from the Auxiliary ELF Vector.
-    """
-    for k,v in sorted(pwndbg.auxv.get().items()):
+    for k, v in sorted(pwndbg.auxv.get().items()):
         if v is not None:
             print(k.ljust(24), v if not isinstance(v, six.integer_types) else pwndbg.chain.format(v))
