@@ -3,8 +3,6 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 
-import argparse
-
 import gdb
 
 import pwndbg.arch
@@ -14,11 +12,7 @@ import pwndbg.regs
 import pwndbg.vmmap
 
 
-p = argparse.ArgumentParser(description='''
-Print out the stack addresses that contain return addresses
-''')
-
-@pwndbg.commands.ArgparsedCommand(p)
+@pwndbg.commands.ArgparsedCommand('Print out the stack addresses that contain return addresses.')
 @pwndbg.commands.OnlyWhenRunning
 def retaddr():
     sp = pwndbg.regs.sp
